@@ -187,7 +187,7 @@ class AbstractModelApp(metaclass=ABCMeta):
         self.tb_logger = None
 
         # 是否使用GPU
-        self.use_cuda = True if self.device_settings.gpu_idx >= 0 else False
+        self.use_cuda = True if torch.cuda.is_available() and self.device_settings.gpu_idx >= 0 else False
 
     def __del__(self):
         """
@@ -279,24 +279,18 @@ class AbstractModelApp(metaclass=ABCMeta):
         """
         raise NotImplementedError
 
-    def set_model_gpu(self, gpu_device_idx=-1):
+    def set_model_gpu(self):
         """
         模型拷贝到GPU中 common
         :return:
         """
-
-        self.device_settings.gpu_idx = gpu_device_idx if gpu_device_idx >= 0 else self.device_settings.gpu_idx
-
-        if self.device_settings.gpu_idx < 0:
-            self.use_cuda = False
+        if self.use_cuda is False:
             return False
 
         try:
-            self.model.cuda(device=self.device_settings.gpu_idx)
-            self.use_cuda = True
+            self.model.cuda(device=self.gpu_device_idx)
         except Exception as ex:
             logging.error("Failed to set model to gpu gpu index=%d %s" % (self.device_settings.gpu_idx, ex))
-            self.use_cuda = False
             return False
 
         return True
@@ -312,9 +306,24 @@ class AbstractModelApp(metaclass=ABCMeta):
             logging.error("Failed to set model to cpu %s" % ex)
             return False
 
-        self.use_cuda = False
         return True
 
+    def set_tensor_gpu(self, x: torch.Tensor) -> torch.Tensor:
+        """
+        tensor拷贝到gpu
+        :param x:
+        :return:
+        """
+        return x.cuda(device=self.gpu_device_idx) if self.use_cuda else x
+
+    def set_tensor_cpu(self, x: torch.Tensor) -> torch.Tensor:
+        """
+        Tensor拷贝到cpu
+        :param x:
+        :return:
+        """
+        return x.cpu()
+
     def set_model_state(self, model_state: ModelState):
         """
         设置模型状态 common
@@ -545,9 +554,7 @@ class AbstractModelApp(metaclass=ABCMeta):
         :return: bool
         """
         self.set_model_state(ModelState.INFERENCE)
-        dummy_input = self.model.get_dummy_input()
-        if self.use_cuda:
-            dummy_input = dummy_input.cuda()
+        dummy_input = self.set_tensor_gpu(self.model.get_dummy_input())
         self.tb_logger.add_graph(self.model, dummy_input)
         self.set_model_state(ModelState.TRAIN)
         return True
