@@ -296,9 +296,7 @@ class IntentEntity(AbstractModelApp):
         :return: bool
         """
         self.set_model_state(ModelState.INFERENCE)
-        dummy_input = self.model.get_dummy_input()
-        if self.use_cuda:
-            dummy_input = dummy_input.cuda()
+        dummy_input = self.set_tensor_gpu(self.model.get_dummy_input())
         self.tb_logger.add_graph(self.model, dummy_input)
         self.set_model_state(ModelState.TRAIN)
         return True
@@ -316,10 +314,7 @@ class IntentEntity(AbstractModelApp):
         )
         self.set_model_state(model_state=ModelState.TRAIN)
         for _, (x, y1, y2) in enumerate(train_data_loader):
-            if self.use_cuda:
-                x = x.cuda()
-                y1 = y1.cuda()
-                y2 = y2.cuda()
+            x, y1, y2 = self.set_tensor_gpu(x), self.set_tensor_gpu(y1),self.set_tensor_gpu(y2)
             y1_, y2_ = self.model(x)
             y2_ = torch.transpose(y2_, dim0=2, dim1=1)
             loss = self.loss_intent_func(y1_, y1) + self.loss_entity_func(y2_, y2)
@@ -364,10 +359,7 @@ class IntentEntity(AbstractModelApp):
 
         self.set_model_state(model_state=ModelState.INFERENCE)
         for _, (x, y1, y2) in enumerate(data_loader):
-            if self.use_cuda:
-                x = x.cuda()
-                y1 = y1.cuda()
-                y2 = y2.cuda()
+            x, y1, y2 = self.set_tensor_gpu(x), self.set_tensor_gpu(y1),self.set_tensor_gpu(y2)
             y1_, y2_ = self.model(x)
             y2_ = torch.transpose(y2_, dim0=2, dim1=1)
             loss_score = loss_score + float(self.loss_intent_func(y1_, y1) + self.loss_entity_func(y2_, y2))
