@@ -300,12 +300,12 @@ class SentDeepCrossRanking(AbstractModelApp):
         """
         self.set_model_state(ModelState.INFERENCE)
         x = self.model.get_dummy_input()
-        user_tokens = x[0].cuda() if self.use_cuda else x[0]
-        user_dense_feature = x[1].cuda() if self.use_cuda else x[1]
-        user_sparse_feature = x[2].cuda() if self.use_cuda else x[2]
-        item_tokens = x[3].cuda() if self.use_cuda else x[3]
-        item_dense_feature = x[4].cuda() if self.use_cuda else x[4]
-        item_sparse_feature = x[5].cuda() if self.use_cuda else x[5]
+        user_tokens = self.set_tensor_gpu(x[0])
+        user_dense_feature = self.set_tensor_gpu(x[1])
+        user_sparse_feature = self.set_tensor_gpu(x[2])
+        item_tokens = self.set_tensor_gpu(x[3])
+        item_dense_feature = self.set_tensor_gpu(x[4])
+        item_sparse_feature = self.set_tensor_gpu(x[5])
         self.tb_logger.add_graph(
             self.model,
             (user_tokens, user_dense_feature, user_sparse_feature, item_tokens, item_dense_feature, item_sparse_feature)
@@ -326,13 +326,13 @@ class SentDeepCrossRanking(AbstractModelApp):
         )
         self.set_model_state(model_state=ModelState.TRAIN)
         for _, (y, x1, x2, x3, x4, x5, x6) in enumerate(train_data_loader):
-            y = y.cuda() if self.use_cuda else y
-            user_tokens = x1.cuda() if self.use_cuda else x1
-            user_dense_feature = x2.cuda() if self.use_cuda else x2
-            user_sparse_feature = x3.cuda() if self.use_cuda else x3
-            item_tokens = x4.cuda() if self.use_cuda else x4
-            item_dense_feature = x5.cuda() if self.use_cuda else x5
-            item_sparse_feature = x6.cuda() if self.use_cuda else x6
+            y = self.set_tensor_gpu(y)
+            user_tokens = self.set_tensor_gpu(x1)
+            user_dense_feature = self.set_tensor_gpu(x2)
+            user_sparse_feature = self.set_tensor_gpu(x3)
+            item_tokens = self.set_tensor_gpu(x4)
+            item_dense_feature = self.set_tensor_gpu(x5)
+            item_sparse_feature = self.set_tensor_gpu(x6)
             y_ = self.model(
                 user_tokens, user_dense_feature, user_sparse_feature,
                 item_tokens, item_dense_feature, item_sparse_feature
@@ -372,13 +372,13 @@ class SentDeepCrossRanking(AbstractModelApp):
 
         self.set_model_state(model_state=ModelState.INFERENCE)
         for _, (y, x1, x2, x3, x4, x5, x6) in enumerate(data_loader):
-            y = y.cuda() if self.use_cuda else y
-            user_tokens = x1.cuda() if self.use_cuda else x1
-            user_dense_feature = x2.cuda() if self.use_cuda else x2
-            user_sparse_feature = x3.cuda() if self.use_cuda else x3
-            item_tokens = x4.cuda() if self.use_cuda else x4
-            item_dense_feature = x5.cuda() if self.use_cuda else x5
-            item_sparse_feature = x6.cuda() if self.use_cuda else x6
+            y = self.set_tensor_gpu(y)
+            user_tokens = self.set_tensor_gpu(x1)
+            user_dense_feature = self.set_tensor_gpu(x2)
+            user_sparse_feature = self.set_tensor_gpu(x3)
+            item_tokens = self.set_tensor_gpu(x4)
+            item_dense_feature = self.set_tensor_gpu(x5)
+            item_sparse_feature = self.set_tensor_gpu(x6)
             y_ = self.model(
                 user_tokens, user_dense_feature, user_sparse_feature,
                 item_tokens, item_dense_feature, item_sparse_feature
